@@ -10,7 +10,7 @@ import tempfile
 import subprocess
 import logging
 
-from doorstop.cli.test import ROOT
+from doorstop.cli.test import ROOT, FILES
 
 ENV = 'TEST_TUTORIAL'  # environment variable to enable the tutorial example
 REASON = "'{0}' variable not set".format(ENV)
@@ -27,8 +27,8 @@ if __name__ == '__main__':
     os.environ[ENV] = '1'  # run the integration tests when called directly
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
-class TestBase(unittest.TestCase):  # pylint: disable=R0904
+@unittest.skipUnless(os.getenv(ENV), REASON)
+class TestBase(unittest.TestCase):
 
     """Base class for tutorial tests."""
 
@@ -53,8 +53,8 @@ class TestBase(unittest.TestCase):  # pylint: disable=R0904
             raise AssertionError("command failed: doorstop {}".format(args))
 
 
-@unittest.skipUnless(os.getenv(ENV), REASON)  # pylint: disable=R0904
-class TestSection1(TestBase):  # pylint: disable=R0904
+@unittest.skipUnless(os.getenv(ENV), REASON)
+class TestSection1(TestBase):
 
     """Integration tests for section 1.0 of the tutorial."""
 
@@ -63,7 +63,7 @@ class TestSection1(TestBase):  # pylint: disable=R0904
 
         # 1.1
 
-        self.doorstop("new REQ ./reqs")
+        self.doorstop("create REQ ./reqs")
 
         self.doorstop("add REQ")
         self.doorstop("add REQ")
@@ -74,7 +74,7 @@ class TestSection1(TestBase):  # pylint: disable=R0904
 
         # 1.2
 
-        self.doorstop("new TST ./reqs/tests --parent REQ")
+        self.doorstop("create TST ./reqs/tests --parent REQ")
 
         self.doorstop("add TST")
         self.doorstop("add TST")
@@ -101,10 +101,10 @@ class TestSection1(TestBase):  # pylint: disable=R0904
         """Verify tutorial section 2.0 is working."""
 
         # Create a basic document
-        self.doorstop("new REQ ./reqs")
+        self.doorstop("create REQ ./reqs")
         self.doorstop("add REQ")
         self.doorstop("add REQ")
-        self.doorstop("new TST ./reqs/tests --parent REQ")
+        self.doorstop("create TST ./reqs/tests --parent REQ")
         self.doorstop("add TST")
         self.doorstop("add TST")
         self.doorstop("link TST1 REQ1")
@@ -123,17 +123,46 @@ class TestSection1(TestBase):  # pylint: disable=R0904
     def test_tutorial_section_3(self):
         """Verify tutorial section 3.0 is working."""
 
-        # 3.1
+        # 3.2
 
         self.doorstop("import --document HLR reqs/hlr")
         self.doorstop("import --document LLR reqs/llr --parent HLR")
 
-        # 3.2
+        # 3.3
 
         self.doorstop("import --item HLR HLR001")
         self.doorstop("import --item LLR LLR001 "
                       "--attr \"{'text': 'The item text.'}\"")
 
+        # 3.1
+
+        dirpath = os.path.join(self.temp, 'path', 'to')
+        os.makedirs(dirpath)
+        path = os.path.join(FILES, 'exported.xlsx')
+        shutil.copy(path, dirpath)
+        self.doorstop("import path/to/exported.xlsx HLR")
+
+    def test_tutorial_section_4(self):
+        """Verify tutorial section 4.0 is working."""
+
+        # Create a basic document
+        self.doorstop("create REQ ./reqs")
+        self.doorstop("add REQ")
+        self.doorstop("add REQ")
+        self.doorstop("create TST ./reqs/tests --parent REQ")
+        self.doorstop("add TST")
+        self.doorstop("add TST")
+        self.doorstop("link TST1 REQ1")
+        self.doorstop("link TST2 REQ1")
+        self.doorstop("link TST2 REQ2")
+
+        # 4.1
+
+        self.doorstop("export TST")
+        self.doorstop("export all dirpath/to/exports")
+        self.doorstop("export REQ path/to/req.xlsx")
+
+
 if __name__ == '__main__':
     logging.basicConfig(format="%(message)s", level=logging.INFO)
     unittest.main()
