@@ -2,4 +2,5 @@
 
 from doorstop.core.item import Item
 from doorstop.core.document import Document
-from doorstop.core.tree import Tree, build, find_document, find_item
+from doorstop.core.tree import Tree
+from doorstop.core.builder import build, find_document, find_item
