@@ -610,7 +610,7 @@ class TestItem(unittest.TestCase):
         self.item.tree = mock_tree
         self.item.links = [{'mock_uid': True}]
         self.assertTrue(self.item.validate())
-        self.assertEqual('abc123', self.item.links[0].stamp)  # pylint: disable=E1101
+        self.assertEqual('abc123', self.item.links[0].stamp)
 
     def test_validate_nonnormative_with_links(self):
         """Verify a non-normative item with links can be checked."""
@@ -702,6 +702,7 @@ class TestItem(unittest.TestCase):
 
         def mock_iter(seq):
             """Creates a mock __iter__ method."""
+
             def _iter(self):  # pylint: disable=W0613
                 """Mock __iter__method."""
                 yield from seq
@@ -781,12 +782,12 @@ class TestItem(unittest.TestCase):
         self.item.tree = mock_tree
         self.item.link('mock_uid')
         self.assertFalse(self.item.cleared)
-        self.assertEqual(None, self.item.links[0].stamp)  # pylint: disable=E1101
+        self.assertEqual(None, self.item.links[0].stamp)
         # Act
         self.item.clear()
         # Assert
         self.assertTrue(self.item.cleared)
-        self.assertEqual('abc123', self.item.links[0].stamp)  # pylint: disable=E1101
+        self.assertEqual('abc123', self.item.links[0].stamp)
 
     def test_review(self):
         """Verify an item can be marked as reviewed."""
@@ -829,6 +830,7 @@ class TestFormatting(unittest.TestCase):
         item.load()
         item.save()
         text = common.read_text(self.ITEM)
+        self.maxDiff = None
         self.assertEqual(self.backup, text)
 
 
