@@ -2,10 +2,13 @@
 
 import os
 
+from doorstop import common
 from doorstop.core.vcs.base import BaseWorkingCopy
 
+log = common.logger(__name__)
 
-class WorkingCopy(BaseWorkingCopy):  # pragma: no cover (integration test)
+
+class WorkingCopy(BaseWorkingCopy):
 
     """Subversion working copy."""
 
@@ -16,15 +19,24 @@ class WorkingCopy(BaseWorkingCopy):  # pragma: no cover (integration test)
         self.call('svn', 'update')
         self.call('svn', 'lock', path)
 
-    def save(self, message=None):
+    def edit(self, path):
+        log.debug("`svn` adds all changes")
+
+    def add(self, path):
+        self.call('svn', 'add', path)
+
+    def delete(self, path):
+        self.call('svn', 'delete', path)
+
+    def commit(self, message=None):
         message = message or input("Commit message: ")  # pylint: disable=W0141
-        self.call('svn', 'commit', '-m', message)
+        self.call('svn', 'commit', '--message', message)
 
     @property
-    def ignores(self):
-        if not self._ignores:
+    def ignores(self):  # pragma: no cover (manual test)
+        if not self._ignores_cache:
             os.chdir(self.path)
             for line in self.call('svn', 'pg', '-R', 'svn:ignore', '.',
                                   return_stdout=True).splitlines():
-                self._ignores.append(line)
-        return self._ignores
+                self._ignores_cache.append(line)
+        return self._ignores_cache
